#!%PERL%
# Copyright (c) vhffs project and its contributors
# Copyright (c) 2007 Julien Danjou <julien@danjou.info>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

package Vhffs::Robots::Git;

use Vhffs::Services::Git;
use Vhffs::Constants;
use Vhffs::Functions;

sub create_repo
{
	my( $main , $git ) = @_;


	my $dir;
	my $dir2;
	my $apache_file;
	my $user_file;

	if( defined $git ) 
	{
	    $dir = $git->get_dir;
	    
	    if( $git->get_status == Vhffs::Constants::WAITING_FOR_CREATION )
	    {
    		my $ok = 1;
		
	    	if( ! -e $dir ) {
		        Vhffs::Functions::create_dir( $dir ) if( ! -d $dir );
		        $git->add_history("Ok, robots find the empty directory and will create git repository");
    			system("cd $dir && git --bare init > /dev/null");

                # Write a description to enhance push mails.
                open DESCRIPTION, ">$dir/description";
                print DESCRIPTION $git->get_reponame."\n";
                close DESCRIPTION;

	    		Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
		        Vhffs::Functions::change_owner_recur( $dir , $git->get_owner_uid , $git->get_owner_gid );

			# .'/hooks' directory must be owned by root to prevent abuse of servers
	    		Vhffs::Functions::chmod_recur( $dir.'/hooks' , 0644 , 0755 );
		        Vhffs::Functions::change_owner_recur( $dir.'/hooks' , 0 , 0 );

    			$git->add_history("The Robots created the git repository");
                } else {
	    		$ok = 0;
			#TODO support syslog
			$git->set_status( Vhffs::Constants::CREATING_ERROR );
    			$git->commit();
	    		$git->add_history("Error, directory of this git repository already exists! Administrators must fix the problem.");
	        }
		if( $ok == 1 ) {
			$git->set_status( Vhffs::Constants::ACTIVATED );
		    
			if( $git->commit < 0 ) {
				$git->add_history("Cannot commit changes on the object!");
	    	  	} else {
		   	 	$git->add_history("Git repository is now active");
		        }
		} else {
		        $git->add_history("Object is not created, problem while creating it");
    		}
            }
	}
}

sub change_conf {
    my $git = shift;
    my $dir = $git->get_dir;
    my $mail_from = $git->get_main->get_config->get_service('git')->{notify_from};

    # Always unlink since git init create a dummy post-receive
    unlink "$dir/hooks/post-receive";
    if($git->get_ml_name !~ /^\s*$/) {
        if(! -e "$dir/hooks/post-receive") {
            system("cp %VHFFS_BOTS_DIR%/misc/git_post-receive $dir/hooks/post-receive");
        }
        system("git-config -f $dir/config hooks.mailinglist ".$git->{ml_name});
        system("git-config -f $dir/config hooks.envelopesender $mail_from");
    }
}

sub delete_repo
{
	my $main = shift;
	my $git = shift;

	my $dir;
	my $dir2;

	if( defined $git ) {
	    $dir = $git->get_dir;
	    system("rm -rf $dir 2>/dev/null");
	    $git->delete;
    } else {
	    return -1;
	}
	
	return 1;
}


1;

